pub struct MemoryEntry { /* private fields */ }Trait Implementations
Sourceimpl Clone for MemoryEntry
impl Clone for MemoryEntry
Sourcefn clone(&self) -> MemoryEntry
fn clone(&self) -> MemoryEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl HasPyGilRef for MemoryEntry
impl HasPyGilRef for MemoryEntry
Sourcetype AsRefTarget = PyCell<MemoryEntry>
type AsRefTarget = PyCell<MemoryEntry>
Utility type to make Py::as_ref work.
Sourceimpl PyClass for MemoryEntry
impl PyClass for MemoryEntry
Sourceimpl PyClassImpl for MemoryEntry
impl PyClassImpl for MemoryEntry
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourcetype ThreadChecker = SendablePyClass<MemoryEntry>
type ThreadChecker = SendablePyClass<MemoryEntry>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a MemoryEntry
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a MemoryEntry
Sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut MemoryEntry
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut MemoryEntry
Sourceimpl PyTypeInfo for MemoryEntry
impl PyTypeInfo for MemoryEntry
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> &PyType
fn type_object(py: Python<'_>) -> &PyType
👎Deprecated since 0.21.0:
PyTypeInfo::type_object will be replaced by PyTypeInfo::type_object_bound in a future PyO3 version
Returns the safe abstraction over the type object.
Sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourcefn is_type_of(object: &PyAny) -> bool
fn is_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_type_of will be replaced by PyTypeInfo::is_type_of_bound in a future PyO3 version
Checks if
object is an instance of this type or a subclass of this type.Sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.Sourcefn is_exact_type_of(object: &PyAny) -> bool
fn is_exact_type_of(object: &PyAny) -> bool
👎Deprecated since 0.21.0:
PyTypeInfo::is_exact_type_of will be replaced by PyTypeInfo::is_exact_type_of_bound in a future PyO3 version
Checks if
object is an instance of this type.impl DerefToPyAny for MemoryEntry